#ifndef FLYICON_H
#define FLYICON_H

#include <flyintegration_global.h>

#include <QIcon>
#include <QMap>

#include <utility>

class FLYINTEGRATION_EXPORT FlyIcon
{
public:
    using Emblem = std::pair<Qt::Corner, QString>;
    using Emblems = QMap<Qt::Corner, QString>;

    static QIcon fromTheme(const QString &name, const Emblem &emblem, const QIcon &fallback = QIcon());
    static QIcon fromTheme(const QString &name, const Emblems &emblems, const QIcon &fallback = QIcon());

    static QIcon withEmblems(const QIcon &icon, const Emblem &emblem);
    static QIcon withEmblems(const QIcon &icon, const Emblems &emblems);

    using OverlaySizeMappingFunction = int (*)(int);
    static QIcon withOverlay(const QIcon &icon, Qt::Corner overlayCorner, const QIcon &overlayIcon,
                             OverlaySizeMappingFunction getOverlaySize = nullptr);

    class ThemePrivate;
    class Theme
    {
    public:
        Theme(const QString &name);
        ~Theme();
        Theme(const Theme &other);
        Theme(Theme &&other);
        Theme &operator=(const Theme &other);
        Theme &operator=(Theme &&other);

        QIcon icon(const QString &name);
    private:
        ThemePrivate *d;
    };

private:
    FlyIcon() = delete;
    ~FlyIcon() = delete;
};

namespace FlyIconLiterals
{
    inline FlyIcon::Emblem operator "" _TL(const char *str, std::size_t len)
    {
        return { Qt::TopLeftCorner, QString::fromUtf8(str, len) };
    }

    inline FlyIcon::Emblem operator "" _TR(const char *str, std::size_t len)
    {
        return { Qt::TopRightCorner, QString::fromUtf8(str, len) };
    }

    inline FlyIcon::Emblem operator "" _BL(const char *str, std::size_t len)
    {
        return { Qt::BottomLeftCorner, QString::fromUtf8(str, len) };
    }

    inline FlyIcon::Emblem operator "" _BR(const char *str, std::size_t len)
    {
        return { Qt::BottomRightCorner, QString::fromUtf8(str, len) };
    }
}

#endif // FLYICON_H
