#ifndef FLYINTEGRATION_H
#define FLYINTEGRATION_H

#include <flyintegration_global.h>

#include <QRect>

class QSettings;
class QWidget;

//extract (resolving symlinks) name from args:
// - argv[0] or
// - "-name" value (if any)
FLYINTEGRATION_EXPORT QString flyAppName();

FLYINTEGRATION_EXPORT QString flyAppDescription();

//set
// - translators for flyui, flyuiextra, app itself
// - help for app
// - in QCoreApplication: appname, appversion, company
// - description as global translated flyAppDescription string
//       to use in FlyAboutDialog by default, use form:
//       flyInit("x.y.z", QT_TRANSLATE_NOOP("Fly","...some description..."),
//       where "Fly" is required keyword!
// - todo: other things in future (pixmap providers for file dialogs, etc.

FLYINTEGRATION_EXPORT void flyInit(const char *ver = "2.0.0", const char *description = nullptr);

//the same as in Qt (excluding position - x,y)
FLYINTEGRATION_EXPORT QByteArray flySaveGeometry(const QWidget *w);
FLYINTEGRATION_EXPORT bool       flyRestoreGeometry(QWidget *w, const QByteArray &geometry);

//save/restore geometry in [FlyGeometry] section in readable form
// screen=
// x=
// y=
// width=
// height=
// frame_x=
// frame_y=
// frame_width=
// frame_height=
// maximized=true/false
// fullScreen=true/false
#define FLY_GEOMETRY_GROUP "FlyGeometry"
FLYINTEGRATION_EXPORT bool flySaveGeometry(const QWidget *w, QSettings *s, bool savePosition = false);
FLYINTEGRATION_EXPORT bool flyRestoreGeometry(QWidget *w,    QSettings *s, const QRect &defaultGeometry = QRect(), bool restorePosition = false);

//return true/false if current Qt style contains 'tablet' keyword
FLYINTEGRATION_EXPORT bool flyInTabletMode();

FLYINTEGRATION_EXPORT QString flyLanguageCode();

FLYINTEGRATION_EXPORT qreal flyDpiScaled(qreal value);

#endif // FLYINTEGRATION_H
